// _MainMenu_EOArchive.java
// Generated by EnterpriseObjects palette at woensdag 17 augustus 2005 22:58:12 uur
// Europe/Amsterdam

import com.webobjects.eoapplication.*;
import com.webobjects.eocontrol.*;
import com.webobjects.eointerface.*;
import com.webobjects.eointerface.swing.*;
import com.webobjects.foundation.*;
import javax.swing.*;

public class _MainMenu_EOArchive extends com.webobjects.eoapplication.EOArchive {

    public _MainMenu_EOArchive(Object owner, NSDisposableRegistry registry)
    {
        super(owner, registry);
    }

    protected void _construct()
    {
        Object                                 owner = _owner();
        EOArchive._ObjectInstantiationDelegate delegate =
            (owner instanceof EOArchive._ObjectInstantiationDelegate)
                ? (EOArchive._ObjectInstantiationDelegate)owner
                : null;
        Object replacement;

        super._construct();
    }

    protected void _awaken()
    {
        super._awaken();
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    _owner(), "unhideAllApplications", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(_owner(),
                                                                            "hide", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    _owner(), "hideOtherApplications", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    _owner(), "orderFrontStandardAboutPanel", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    _owner(), "terminate", ),
                ""));
    }

    protected void _init()
    {
        super._init();
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "performMiniaturize", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "performFindPanelAction", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "selectAll", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(null,
                                                                            "undo", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "performFindPanelAction", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "stopSpeaking", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(null,
                                                                            "print", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "pasteAsPlainText", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "startSpeaking", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "toggleContinuousSpellChecking", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "performFindPanelAction", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "checkSpelling", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(null,
                                                                            "redo", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "runPageLayout", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(null,
                                                                            "showHelp", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "showGuessPanel", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(null,
                                                                            "paste", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "performZoom", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "clearRecentDocuments", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "performClose", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "arrangeInFront", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "openDocument", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(null,
                                                                            "cut", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "centerSelectionInVisibleArea", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(
                    null, "performFindPanelAction", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(null,
                                                                            "copy", ),
                ""));
        .addActionListener(
            (com.webobjects.eointerface.swing.EOControlActionAdapter)_registered(
                new com.webobjects.eointerface.swing.EOControlActionAdapter(null,
                                                                            "delete", ),
                ""));
    }
}
